@@ -197,6 +197,20 @@ format.tbl_ddf <- function(x, n = NULL, ...) {
                 ...)
 }
 
+#' @export
+tbl_sum.tbl_ddf <- function(x) {
+  dim_names <- dimnames(x)
+  dim <- list_sizes_unnamed(dim_names)
+  size_dim <- prod(dim)
+  meas_names <- colnames(x)
+  size_meas <- big_mark(vec_size(meas_names))
+
+  c(`A dibble` = paste(big_mark(size_dim), size_meas,
+                       sep = " x "),
+    `Dimensions` = commas(paste0(names(dim_names), " [", big_mark(dim), "]")),
+    `Measures` = commas(meas_names))
+}
+
 #' @export
 tbl_format_setup.tbl_ddf <- function(x, width = NULL, ..., n = NULL, max_extra_cols = NULL, max_footer_lines = NULL, focus = NULL) {
   tbl_format_setup_dibble(x,
